<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:variable name="Component" select="/OMA/Component"/>
	<xsl:variable name="Snb" select="/OMA/Snb"/>
	<xsl:template match="/OMA">
		<xsl:apply-templates select="IncludePath"/>
		<xsl:apply-templates select="Session/Differences/Empty"/>
		<xsl:apply-templates select="TestCollection"/>
	</xsl:template>
	<xsl:template match="TestCollection">
		<DataArea validate="false" expand="true" exportdata="false">
			<xsl:attribute name="submit">/servlet/SubmitForm?plugin=com.dell.omaha.webplugins.DiagnosticDiffWebPlugin&amp;ct=<xsl:value-of select="$Component"/>&amp;snb=<xsl:value-of select="$Snb"/>&amp;lsnb=DiagDiff</xsl:attribute>
			<xsl:attribute name="submitdisplay"><xsl:value-of select="$strACKNOWLEDGE"/></xsl:attribute>
			<xsl:call-template name="DisplayPageTitle"/>
			<CustomButton>
				<Data name="Diff History">
					<xsl:attribute name="display"><xsl:value-of select="$strHWCHANGEHISTORY"/></xsl:attribute>
					<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticDiffHistoryWebPlugin&amp;ct=<xsl:value-of select="$Component"/>&amp;snb=<xsl:value-of select="$Snb"/>&amp;lsnb=DiagDiff</xsl:attribute>
				</Data>
			</CustomButton>
			<PromptText>
				<xsl:value-of select="$strPROMPTTEXT"/>
			</PromptText>
			<SelectionData multitable="false">
				<SelectionTable>
					<xsl:apply-templates select="/OMA/TestCollection" mode="DisplayDevices"/>
				</SelectionTable>
			</SelectionData>
		</DataArea>
	</xsl:template>
	<!-- ################### 
	       Create Collection XML
	      ################### -->
	<xsl:template match="TestCollection" mode="DisplayDevices">
		<xsl:for-each select="Device">
			<xsl:call-template name="DeviceMatch"/>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="DeviceMatch">
		<Row tree="expand">
			<xsl:attribute name="name"><xsl:value-of select="@parentlocation"/><xsl:value-of select="@location"/></xsl:attribute>
			<SelectDataItem>
				<!-- Display a blank box in case there are children elements -->
				<xsl:if test="not(Device)">
					<Data>
						<xsl:attribute name="width">20</xsl:attribute>
					</Data>
				</xsl:if>
				<!-- Input checkbox id = name................................ -->
				<Data>
					<xsl:attribute name="name">AddedRemoved</xsl:attribute>
					<xsl:attribute name="type">icon</xsl:attribute>
					<xsl:attribute name="width">20</xsl:attribute>
					<xsl:choose>
						<xsl:when test="@diffstatus='0'">
							<xsl:attribute name="value">/oldiags/images/ok.gif</xsl:attribute>
							<xsl:attribute name="alt"><xsl:value-of select="$strADDED"/></xsl:attribute>
						</xsl:when>
						<xsl:when test="@diffstatus='1'">
							<xsl:attribute name="value">/oldiags/images/Critical.gif</xsl:attribute>
							<xsl:attribute name="alt"><xsl:value-of select="$strSUBTRACTED"/></xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="value">/oma/images/blank.gif</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
				</Data>
			</SelectDataItem>
			<ColumnData>
				<!-- Display Text ................................ -->
				<Data>
					<xsl:attribute name="value"><xsl:value-of select="@name"/></xsl:attribute>
				</Data>
			</ColumnData>
			<xsl:choose>
				<xsl:when test="Device">
					<xsl:for-each select="Device">
						<xsl:sort select="normalize-space(@sortname)"/>
						 	<xsl:sort select="@sortindex" data-type="number" order="ascending"/>

						<ChildrenRows>
							<xsl:call-template name="DeviceMatch"/>
						</ChildrenRows>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise/>
			</xsl:choose>
		</Row>
	</xsl:template>
	<!-- ################### 
	       Display Page Title 
	      ################### -->
	<xsl:template name="DisplayPageTitle">
		<PageTitle>
			<xsl:attribute name="display"><xsl:value-of select="$strHWCONFIGCHG"/></xsl:attribute>
		</PageTitle>
	</xsl:template>
	<xsl:template match="Session/Differences/Empty">
		<DataArea>
			<xsl:attribute name="exportdata">false</xsl:attribute>
			<xsl:attribute name="expand">false</xsl:attribute>
			<xsl:attribute name="expandl">false</xsl:attribute>
			<xsl:attribute name="email">false</xsl:attribute>
			<xsl:attribute name="printable">false</xsl:attribute>
			<xsl:call-template name="DisplayPageTitle"/>
			<CustomButton>
				<Data name="Diff History">
					<xsl:attribute name="display"><xsl:value-of select="$strHWCHANGEHISTORY"/></xsl:attribute>
					<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticDiffHistoryWebPlugin&amp;ct=<xsl:value-of select="$Component"/>&amp;snb=<xsl:value-of select="$Snb"/>&amp;lsnb=DiagDiff</xsl:attribute>
				</Data>
			</CustomButton>
			<TableData>
				<Row>
					<xsl:element name="Data">
						<xsl:attribute name="value"><xsl:value-of select="$strNOHWCONFIGCHG"/></xsl:attribute>
					</xsl:element>
				</Row>
			</TableData>
		</DataArea>
	</xsl:template>
	<xsl:template match="IncludePath">
		<xsl:element name="xsl:include">
			<xsl:attribute name="href">file:<xsl:value-of select="."/></xsl:attribute>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>
