<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:variable name="Component" select="/OMA/Component"/>
	<xsl:variable name="Snb" select="/OMA/Snb"/>
	<xsl:variable name="BASEURL">/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticScheduleWebPlugin&amp;ct=<xsl:value-of select="$Component"/>&amp;snb=<xsl:value-of select="$Snb"/></xsl:variable>
	<xsl:variable name="SUBMITURL">/servlet/SubmitForm?plugin=com.dell.omaha.webplugins.DiagnosticScheduleWebPlugin&amp;ct=<xsl:value-of select="$Component"/>&amp;snb=<xsl:value-of select="$Snb"/></xsl:variable>

	<xsl:template match="/OMA">
		<xsl:apply-templates select="IncludePath"/>
		<xsl:variable name="displayView" select="/OMA/Action"/>
		<DataArea exportdata="false">
			<xsl:choose>
				<xsl:when test="$displayView = 'RESCHEDULETASK'">
					<xsl:attribute name="validate">true</xsl:attribute>
					<xsl:choose>
						<xsl:when test="/OMA/Status/MessageType = 'PASTSCHEDULING'">
							<xsl:call-template name="ViewTestList">
								<xsl:with-param name="mode"><xsl:value-of select="'reschedule'"/></xsl:with-param>
							</xsl:call-template>
						</xsl:when>
						<xsl:when test="/OMA/Status/MessageType = 'DUPLICATE'">
							<xsl:call-template name="ViewTestList">
								<xsl:with-param name="mode"><xsl:value-of select="'reschedule'"/></xsl:with-param>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="DisplayStatus">
								<xsl:with-param name="mode"><xsl:value-of select="$displayView"/></xsl:with-param>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>					
				</xsl:when>
				<xsl:when test="$displayView = 'VIEWTASKDETAILS'">
					<xsl:attribute name="validate">true</xsl:attribute>
					<xsl:call-template name="ViewTestList">
						<xsl:with-param name="mode"><xsl:value-of select="'reschedule'"/></xsl:with-param>
					</xsl:call-template>
				</xsl:when>
				<xsl:when test="$displayView = 'SCHEDULETASK'">
					<xsl:attribute name="validate">true</xsl:attribute>
					<xsl:call-template name="DisplayStatus">
						<xsl:with-param name="mode"><xsl:value-of select="$displayView"/></xsl:with-param>
					</xsl:call-template>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="validate">true</xsl:attribute>
					<xsl:call-template name="ViewTestList">
						<xsl:with-param name="mode"><xsl:value-of select="'schedule'"/></xsl:with-param>
					</xsl:call-template>
				</xsl:otherwise>
			</xsl:choose>
		</DataArea>
	</xsl:template>

	<!-- ########################################################################## -->
	<!-- Display Status -->
	<xsl:template name="DisplayStatus">
		<xsl:param name="mode"/>
		<xsl:attribute name="printable">false</xsl:attribute>
		<xsl:attribute name="email">false</xsl:attribute>
		
		<xsl:variable name="mesgType">
			<xsl:value-of select="/OMA/Status/MessageType"/>
		</xsl:variable>
		
		<xsl:if test="$mesgType = 'SUCCESS'">
			<xsl:attribute name="submitdisplay"><xsl:value-of select="$strTASKLIST"/></xsl:attribute>
			<xsl:attribute name="submit">/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticReviewScheduledWebPlugin&amp;ct=<xsl:value-of select="$Component"/>&amp;snb=<xsl:value-of select="$Snb"/>&amp;lsnb=DiagScheduledTask</xsl:attribute>
		</xsl:if>

		<xsl:call-template name="ViewSchedulePageTitle"/>
		<xsl:call-template name="IncludeJavaScriptCode"/>
		<PromptText>
			<xsl:choose>
				<xsl:when test="$mesgType = 'SUCCESS'">
					<xsl:if test="$mode = 'SCHEDULETASK'">
						<xsl:value-of select="$strSCHEDULEDPROMPT"/>
					</xsl:if>
					<xsl:if test="$mode = 'RESCHEDULETASK'">
						<xsl:value-of select="$strRESCHEDULEDPROMPT"/>
					</xsl:if>
				</xsl:when>
				<xsl:when test="$mesgType = 'SCHEDULER_ERROR'">
					<xsl:value-of select="$strSCHEDULERERROR"/>
				</xsl:when>
				<xsl:when test="$mesgType = 'UNSUPPORTEDENCODING'">
					<xsl:value-of select="$strUNSUPPORTEDENCODING"/>
				</xsl:when>
			</xsl:choose>
		</PromptText>
	</xsl:template>

	<!-- ########################################################################## -->
	<!-- Display Review Scheduled-->
	<xsl:template name="ViewTestList">
		<xsl:param name="mode"/>
		<xsl:attribute name="printable">false</xsl:attribute>
		<xsl:attribute name="expand">false</xsl:attribute>
		<xsl:attribute name="expandl">false</xsl:attribute>
		<xsl:attribute name="email">false</xsl:attribute>
		<xsl:attribute name="date">true</xsl:attribute>

		<xsl:if test="$mode = 'schedule'">
			<xsl:attribute name="submitdisplay"><xsl:value-of select="$strSCHEDULE"/></xsl:attribute>
			<xsl:attribute name="submit"><xsl:value-of select="$SUBMITURL"/>&amp;lsnb=DiagScheduledTask&amp;action=ScheduleTask</xsl:attribute>
		</xsl:if>
		<xsl:if test="$mode = 'reschedule'">
			<xsl:attribute name="submitdisplay"><xsl:value-of select="$strRESCHEDULE"/></xsl:attribute>
			<xsl:attribute name="submit"><xsl:value-of select="$SUBMITURL"/>&amp;lsnb=DiagScheduledTask&amp;action=RescheduleTask&amp;TaskId=<xsl:value-of select="DiagScheduledTask/@IDENTIFIER"/></xsl:attribute>
		</xsl:if>

		<xsl:call-template name="ViewSchedulePageTitle"/>
		<xsl:call-template name="IncludeJavaScriptCode"/>

		<xsl:variable name="mesgType">
			<xsl:value-of select="/OMA/Status/MessageType"/>
		</xsl:variable>

		<xsl:if test="$mode = 'schedule'">
		<PromptText>
				<xsl:choose>
					<!-- Scheduling Past is not allowed -->
					<xsl:when test="$mesgType = 'PASTSCHEDULING'">
						<xsl:value-of select="$strSCHEDPASTPROMPTTEXT"/>
					</xsl:when>
					<!-- Duplicate Task Name is not allowed -->
					<xsl:when test="$mesgType = 'DUPLICATE'">
						<xsl:value-of select="$strSCHEDULEDDUPLICATE"/>						
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$strPROMPTTEXT"/>
					</xsl:otherwise>
				</xsl:choose>				
		</PromptText>
		<CustomButton>
				<Data name="moretestbutton">
					<xsl:attribute name="display"><xsl:value-of select="$strSELECTMORETESTS"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="$strSELECTMORETESTS"/></xsl:attribute>
					<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticSelectionWebPlugin&amp;ct=<xsl:value-of select="$Component"/>&amp;snb=<xsl:value-of select="$Snb"/>&amp;lsnb=Select</xsl:attribute>
				</Data>
		</CustomButton>
		</xsl:if>

		<xsl:if test="$mode = 'reschedule'">
		<PromptText>
				<xsl:choose>
					<!-- Scheduling Past is not allowed -->
					<xsl:when test="$mesgType = 'PASTSCHEDULING'">
						<xsl:value-of select="$strRESCHEDPASTPROMPTTEXT"/>
					</xsl:when>
					<!-- Duplicate Task Name is not allowed -->
					<xsl:when test="$mesgType = 'DUPLICATE'">
						<xsl:value-of select="$strSCHEDULEDDUPLICATE"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$strRESCHEDULINGPROMPT"/>
					</xsl:otherwise>
				</xsl:choose>				
		</PromptText>

		<CustomButton>
				<Data name="taskresultsbutton">
					<xsl:attribute name="display"><xsl:value-of select="$strTASKRESULTS"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="$strTASKRESULTS"/></xsl:attribute>
					<xsl:attribute name="href">javascript:viewResultsByTask()</xsl:attribute>
					<xsl:attribute name="formSubmit">true</xsl:attribute>
				</Data>
		</CustomButton>

		</xsl:if>

		<CustomButton>
			<Data name="ReviewScheduled">
					<xsl:attribute name="display"><xsl:value-of select="$strTASKLIST"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="$strTASKLIST"/></xsl:attribute>
					<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticReviewScheduledWebPlugin&amp;action=ReviewScheduled&amp;ct=<xsl:value-of select="$Component"/>&amp;snb=<xsl:value-of select="$Snb"/>&amp;lsnb=DiagScheduledTask</xsl:attribute>
			</Data>
		</CustomButton>
		<xsl:call-template name="DisplayDateTime"/>
		<xsl:call-template name="DisplayTestList"/>
	</xsl:template>

	<!-- ########################################################################## -->
	<!-- JavaScript -->
	<xsl:template name="IncludeJavaScriptCode">
		<script language="javascript">
			function viewResultsByTask()	{
				document.dataarea.action='<xsl:value-of select="$SUBMITURL"/>&amp;lsnb=DiagScheduledTask&amp;action=ViewByTask';
				document.getElementById("ViewByTask").value = "true";
				document.dataarea.submit();
			}
		
			function validate() {
				var actionString = document.dataarea.action;
				//alert('actionString = ' + actionString);
				if (actionString != null &amp;&amp; actionString.indexOf("DiagnosticReviewScheduledWebPlugin") != -1) {
					return true;
				}

				//alert('validate called');
				var errorMessage = "";

				var taskName  = document.getElementById("TaskName").value ;
				var taskDesc   = document.getElementById("TaskDesc").value ;
				var hourValue  = document.getElementById("HourValue").value ;
 				var minValue  = document.getElementById("MinValue").value ;
				var calValue  = document.getElementById("OldCalendar").value ;
				
				if ( ( calValue.length != 0 ) &amp;&amp; ( !isNaN( calValue ) ) )
				{
					var date = new Date( new Number(calValue) );
					//Client's GMT offset
					document.getElementById("ClientGmtOffset").value = date.getTimezoneOffset();
				}
	
				var trimmedTaskName = strtrim(taskName);
				var trimmedTaskDesc = strtrim(taskDesc);

				if (trimmedTaskName.length == 0) {
					errorMessage += "<xsl:value-of select="$strTASKNAMEBLANK"/>";
				} else if (trimmedTaskDesc.length == 0) {
					errorMessage += "<xsl:value-of select="$strTASKDESCBLANK"/>";
				} else if (calValue.length == 0) {
					errorMessage += "<xsl:value-of select="$strSTARTDATEBLANK"/>";
				} else {
					var onechecked = false;
					var frequencies = document.getElementsByName("Frequency");
					for (var i = 0; i &lt; 4; i++) {
						if (frequencies[i].checked) {
							onechecked = true;
							break;
						}
					}
					if (!onechecked) {
						errorMessage += "<xsl:value-of select="$strFREQUENCYBLANK"/>";
					}
				}

				if (errorMessage != "") {
					alert(errorMessage);
					return false;
				}

				
				if (!isValid(trimmedTaskName)) {
					errorMessage += "<xsl:value-of select="$strINVALIDCHARTASKNAME"/>";
				}

				if (errorMessage != "") {
					alert(errorMessage);
					return false;
				}

				if (!isValid(trimmedTaskDesc)) {
					errorMessage += "<xsl:value-of select="$strINVALIDCHARTASKDESC"/>";
				}

				if (<xsl:value-of select="count(.//DeviceTestPair)"/> &lt;= 0) {
					errorMessage += "<xsl:value-of select="$strNoSELECTEDTESTS"/>";
				}
				
				if (errorMessage != "") {
					alert(errorMessage);
					return false;
				}
				
				return true;
			}

			//check for special characters in string object
			//TBD : check with UNICODE characters
			// <!-- ',", <, >, &, \ are not allowed -->
			function isValid(strObj) {
				for (var i = 0; i &lt; strObj.length; i++) {
					if (strObj.charCodeAt(i) == 0x27 ||
					    strObj.charCodeAt(i) == 0x22 ||
					    strObj.charCodeAt(i) == 0x3C ||
					    strObj.charCodeAt(i) == 0x3E ||
					    strObj.charCodeAt(i) == 0x26 ||
					    strObj.charCodeAt(i) == 0x5C) 
					{
						return false;
					}
				}
				return true;
			}

			function strtrim(str) {				
				//Match spaces at beginning and end of text and replace with null strings 
				return str.replace(/^\s+/,'').replace(/\s+$/,''); 
			}

		</script>
	</xsl:template>

	<!-- ########################################################################## -->
	<xsl:template name="DisplayTestList">
		<TableData  ignoreJumpBar="true" columnspacing="true">
			<Header>
				<Data name="DeviceName" align="center" link="false">
					<xsl:attribute name="value"><xsl:value-of select="$strDEVICENAME"/></xsl:attribute>
					<xsl:attribute name="display"><xsl:value-of select="$strDEVICENAME"/></xsl:attribute>
				</Data>
				<Data name="TestName" align="center" link="false">
					<xsl:attribute name="value"><xsl:value-of select="$strTESTNAME"/></xsl:attribute>
					<xsl:attribute name="display"><xsl:value-of select="$strTESTNAME"/></xsl:attribute>
				</Data>
				<Data name="Current" link="false" colspan="7" align="center" underlined="false">
					<xsl:attribute name="value"><xsl:value-of select="$strCURRENTSETTINGS"/></xsl:attribute>
					<xsl:attribute name="display"><xsl:value-of select="$strCURRENTSETTINGS"/></xsl:attribute>
				</Data>
				<Data name="Locator" link="false" align="center">
					<xsl:attribute name="value"><xsl:value-of select="$strDEVICELOCATOR"/></xsl:attribute>
					<xsl:attribute name="display"><xsl:value-of select="$strDEVICELOCATOR"/></xsl:attribute>
				</Data>
			</Header>
				<Header>
					<Data name="Dummy" value=" " display=" "/>
					<Data name="Dummy" value=" " display=" "/>
					<Data name="QuickTest" link="false" align="center">
						<xsl:attribute name="value"><xsl:value-of select="$strQUICKTEST"/></xsl:attribute>
						<xsl:attribute name="display"><xsl:value-of select="$strQUICKTEST"/></xsl:attribute>
					</Data>
					<Data name="HaltOnError" link="false" align="center">
						<xsl:attribute name="value"><xsl:value-of select="$strHALTERROR"/></xsl:attribute>
						<xsl:attribute name="display"><xsl:value-of select="$strHALTERROR"/></xsl:attribute>
					</Data>
					<Data name="Passes" link="false" align="center">
						<xsl:attribute name="value"><xsl:value-of select="$strNOSPASSES"/></xsl:attribute>
						<xsl:attribute name="display"><xsl:value-of select="$strNOSPASSES"/></xsl:attribute>
					</Data>
					<Data name="RunTime" link="false" align="center">
						<xsl:attribute name="value"><xsl:value-of select="$strRUNTIME"/></xsl:attribute>
						<xsl:attribute name="display"><xsl:value-of select="$strRUNTIME"/></xsl:attribute>
					</Data>
					<Data name="Dummy" value=" " display=" "/>
				</Header>
				<xsl:apply-templates select=".//DeviceTestPair">
					<xsl:sort select="./Device/@name"/>
				</xsl:apply-templates>
		</TableData>
	</xsl:template>

	<!-- ########################################################################## -->
	<xsl:template match="DeviceTestPair">
		<Row>
			<Data name="DeviceName">
				<xsl:attribute name="value"><xsl:value-of select="./Device/@name"/></xsl:attribute>
			</Data>
			<Data name="TestName">
				<xsl:attribute name="value"><xsl:value-of select="./Test/@name"/></xsl:attribute>
			</Data>
			<Data name="SevStatus" type="status" align="center">
				<xsl:choose>
					<xsl:when test="./DiagnosticSettings/@quicktest = 'true'">
						<xsl:attribute name="value">2</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="value">0</xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</Data>
			<Data name="SevStatus" type="status" align="center">
				<xsl:choose>
					<xsl:when test="./DiagnosticSettings/@haltonerror = 'true'">
						<xsl:attribute name="value">2</xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:attribute name="value">0</xsl:attribute>
					</xsl:otherwise>
				</xsl:choose>
			</Data>
			<Data name="Passes" link="false" align="center">
				<xsl:if test="./DiagnosticSettings/@numpasses = -1">
					<xsl:attribute name="value"><xsl:value-of select="$strHYPHEN"/></xsl:attribute>
				</xsl:if>
				<xsl:if test="./DiagnosticSettings/@numpasses != -1 ">
					<xsl:attribute name="value"><xsl:value-of select="./DiagnosticSettings/@numpasses"/></xsl:attribute>
				</xsl:if>
			</Data>
			<Data name="RunTime" link="false" align="center">
				<xsl:if test="./DiagnosticSettings/@runtime = -1">
					<xsl:attribute name="value">-</xsl:attribute>
				</xsl:if>
				<xsl:if test="./DiagnosticSettings/@runtime != -1 ">
					<xsl:attribute name="value"><xsl:value-of select="./DiagnosticSettings/@runtime"/><xsl:value-of select="$strMINUTE"/></xsl:attribute>
				</xsl:if>
			</Data>
			<Data name="DeviceLocation">
				<xsl:attribute name="value"><xsl:value-of select="./Device/@location"/></xsl:attribute>
			</Data>
		</Row>
	</xsl:template>

	<!-- ########################################################################## -->
	<xsl:template name="ViewSchedulePageTitle">
		<PageTitle>
			<xsl:attribute name="display"><xsl:value-of select="$strPAGETITLE"/></xsl:attribute>
		</PageTitle>
	</xsl:template>

	<!-- ########################################################################## -->
	<!-- Display Date,Time,Frequency -->
	<xsl:template name="DisplayDateTime">
		<xsl:variable name="SelectedHour">
			<xsl:choose>
			<xsl:when test="./DiagScheduledTask/SchedulerSettings/@TimeHour">
				<xsl:value-of select="./DiagScheduledTask/SchedulerSettings/@TimeHour"/>
			</xsl:when>
			<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="SelectedMin">
			<xsl:choose>
			<xsl:when test="./DiagScheduledTask/SchedulerSettings/@TimeMinute">
				<xsl:value-of select="./DiagScheduledTask/SchedulerSettings/@TimeMinute"/>
			</xsl:when>
			<xsl:otherwise>0</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<TableData columnspacing="true">
			<Row>				
				<Data>
					<xsl:attribute name="value"><xsl:value-of select="$strTASKNAME"/></xsl:attribute>
					<xsl:attribute name="align">left</xsl:attribute>
				</Data>
				<Data colspan="5">
					<xsl:attribute name="name">TaskName</xsl:attribute>
					<xsl:attribute name="size">10</xsl:attribute>
					<xsl:attribute name="maxlength">25</xsl:attribute>
					<xsl:attribute name="type">editbox</xsl:attribute>
					<xsl:attribute name="align">left</xsl:attribute>
					<xsl:if test="/OMA/Status/MessageType = 'PASTSCHEDULING'">
						<xsl:attribute name="value"><xsl:value-of select="/OMA/Status/Message/@taskname"/></xsl:attribute>
					</xsl:if>
					<xsl:if test="not(/OMA/Status/MessageType = 'DUPLICATE') and ./DiagScheduledTask/@taskname != ''">
						<xsl:attribute name="value"><xsl:value-of select="./DiagScheduledTask/@taskname"/></xsl:attribute>
					</xsl:if>

				</Data>
				<Data>
					<xsl:attribute name="value"><xsl:value-of select="$strTASKDESC"/></xsl:attribute>
					<xsl:attribute name="align">left</xsl:attribute>
				</Data>
				<Data colspan="5">
					<xsl:attribute name="name">TaskDesc</xsl:attribute>
					<xsl:attribute name="size">35</xsl:attribute>
					<xsl:attribute name="maxlength">50</xsl:attribute>
					<xsl:attribute name="type">editbox</xsl:attribute>
					<xsl:attribute name="align">left</xsl:attribute>
					<xsl:choose>
					<xsl:when test="/OMA/Status/MessageType = 'PASTSCHEDULING' or (/OMA/Action = 'RESCHEDULETASK' and /OMA/Status/MessageType = 'DUPLICATE')">
						<xsl:attribute name="value"><xsl:value-of select="/OMA/Status/Message/@taskdesc"/></xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="./DiagScheduledTask/@taskdesc != ''">
							<xsl:attribute name="value"><xsl:value-of select="./DiagScheduledTask/@taskdesc"/></xsl:attribute>
						</xsl:if>
					</xsl:otherwise>
					</xsl:choose>
				</Data>
			</Row>
			<Row>
				<Data>
					<xsl:attribute name="value"><xsl:value-of select="$strSELECTTIME"/></xsl:attribute>
					<xsl:attribute name="align">left</xsl:attribute>
				</Data>
				<Data name="HourValue"  width="10" editable="true" type="select" align="left">
					<xsl:for-each select="HourSelectOption">
						<Choice>
							<xsl:attribute name="returnvalue"><xsl:value-of select="@value"/></xsl:attribute>
							<xsl:attribute name="value"><xsl:value-of select="@display"/></xsl:attribute>
							<xsl:choose>
							<xsl:when test="/OMA/Status/MessageType = 'DUPLICATE'">
								<xsl:if test="/OMA/Status/Message/@hourval = @value">
									<xsl:attribute name="default"><xsl:value-of select="'true'"/></xsl:attribute>
								</xsl:if>
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="$SelectedHour = @value">
									<xsl:attribute name="default"><xsl:value-of select="'true'"/></xsl:attribute>
								</xsl:if>
							</xsl:otherwise>
							</xsl:choose>
						</Choice>
					</xsl:for-each>
				</Data>
				<Data name="MinValue" editable="true" type="select" align="left">
					<xsl:for-each select="MinuteSelectOption">
						<Choice>
							<xsl:attribute name="returnvalue"><xsl:value-of select="@value"/></xsl:attribute>
							<xsl:attribute name="value"><xsl:value-of select="@display"/></xsl:attribute>
							<xsl:choose>
							<xsl:when test="/OMA/Status/MessageType = 'DUPLICATE'">
								<xsl:if test="/OMA/Status/Message/@minuteval = @value">
									<xsl:attribute name="default"><xsl:value-of select="'true'"/></xsl:attribute>
								</xsl:if>								
							</xsl:when>
							<xsl:otherwise>
								<xsl:if test="$SelectedMin = @value">
									<xsl:attribute name="default"><xsl:value-of select="'true'"/></xsl:attribute>
								</xsl:if>
							</xsl:otherwise>
							</xsl:choose>
						</Choice>
					</xsl:for-each>
				</Data>
				<Data colspan="9" value=" "/>
			</Row>
			<Row>
				<Data>
					<xsl:attribute name="value"><xsl:value-of select="$strSELECTDATE"/></xsl:attribute>
					<xsl:attribute name="align">left</xsl:attribute>
				</Data>
				<Data name="OldCalendar" type="date" colspan="11">
					<xsl:choose>			
					<xsl:when test="/OMA/Status/MessageType = 'DUPLICATE'">
						<xsl:attribute name="value"><xsl:value-of select="/OMA/Status/Message/@calendar"/></xsl:attribute>
					</xsl:when>
					<xsl:otherwise>
					<xsl:if test="./DiagScheduledTask/SchedulerSettings/@DateTimeMillis != ''">
						<xsl:attribute name="value"><xsl:value-of select="./DiagScheduledTask/SchedulerSettings/@DateTimeMillis"/></xsl:attribute>
					</xsl:if>
					<xsl:if test="./DiagScheduledTask/SchedulerSettings/@ServerGmtOffset!= ''">
						<xsl:attribute name="srvOffset"><xsl:value-of select="./DiagScheduledTask/SchedulerSettings/@ServerGmtOffset"/></xsl:attribute>
					</xsl:if>
					</xsl:otherwise>
					</xsl:choose>
					<xsl:attribute name="width"><xsl:value-of select="30"/></xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="name">ViewByTask</xsl:attribute>
					<xsl:attribute name="type">hidden</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="'false'"/></xsl:attribute>
				</Data>
				<Data>
					<xsl:attribute name="name">ClientGmtOffset</xsl:attribute>
					<xsl:attribute name="type">hidden</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="'0'"/></xsl:attribute>
				</Data>
			</Row>
			<Row>
				<Data>
					<xsl:attribute name="value"><xsl:value-of select="$strFREQUENCY"/></xsl:attribute>
				</Data>
				<Data type="radio" colspan="3">
					<xsl:attribute name="name">Frequency</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="$strONCE"/></xsl:attribute>
					<xsl:attribute name="returnvalue">0</xsl:attribute>
					<xsl:if test="(/OMA/Status/MessageType = 'PASTSCHEDULING' or /OMA/Status/MessageType = 'DUPLICATE') and /OMA/Status/Message/@frequency = 0">
						<xsl:attribute name="state">1</xsl:attribute>
					</xsl:if>
					<xsl:if test="./DiagScheduledTask/SchedulerSettings/@Frequency = 0">
						<xsl:attribute name="state">1</xsl:attribute>
					</xsl:if>
				</Data>
				<Data type="radio" colspan="3">
					<xsl:attribute name="name">Frequency</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="$strDAILY"/></xsl:attribute>
					<xsl:attribute name="returnvalue">1</xsl:attribute>
					<xsl:if test="(/OMA/Status/MessageType = 'PASTSCHEDULING' or /OMA/Status/MessageType = 'DUPLICATE') and /OMA/Status/Message/@frequency = 1">
						<xsl:attribute name="state">1</xsl:attribute>
					</xsl:if>
					<xsl:if test="./DiagScheduledTask/SchedulerSettings/@Frequency = 1">
						<xsl:attribute name="state">1</xsl:attribute>
					</xsl:if>
				</Data>
				<Data type="radio" colspan="3">
					<xsl:attribute name="name">Frequency</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="$strWEEKLY"/></xsl:attribute>
					<xsl:attribute name="returnvalue">2</xsl:attribute>
					<xsl:if test="(/OMA/Status/MessageType = 'PASTSCHEDULING' or /OMA/Status/MessageType = 'DUPLICATE') and /OMA/Status/Message/@frequency = 2">
						<xsl:attribute name="state">1</xsl:attribute>
					</xsl:if>
					<xsl:if test="./DiagScheduledTask/SchedulerSettings/@Frequency = 2">
						<xsl:attribute name="state">1</xsl:attribute>
					</xsl:if>
				</Data>
				<Data type="radio">
					<xsl:attribute name="name">Frequency</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="$strMONTHLY"/></xsl:attribute>
					<xsl:attribute name="returnvalue">3</xsl:attribute>
					<xsl:if test="(/OMA/Status/MessageType = 'PASTSCHEDULING' or /OMA/Status/MessageType = 'DUPLICATE') and /OMA/Status/Message/@frequency = 3">
						<xsl:attribute name="state">1</xsl:attribute>
					</xsl:if>
					<xsl:if test="./DiagScheduledTask/SchedulerSettings/@Frequency = 3">
						<xsl:attribute name="state">1</xsl:attribute>
					</xsl:if>
				</Data>
			</Row>			
		</TableData>
	</xsl:template>


	<xsl:template match="IncludePath">
		<xsl:element name="xsl:include">
			<xsl:attribute name="href">file:<xsl:value-of select="."/></xsl:attribute>
		</xsl:element>
	</xsl:template>
	<xsl:template match="*"/>
</xsl:stylesheet>
