<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:variable name="SEPARATOR" select="'_'"/>
	<xsl:variable name="BANG" select="'!'"/>
	<xsl:key name="Test-Key-By-Name" match="Test" use="@name"/>
	<xsl:template match="/OMA">
		<xsl:apply-templates select="IncludePath"/>
		<DataArea validate="true" exportdata="false">
			<xsl:variable name="displayview" select="DisplayView"/>
			<xsl:if test="/OMA/DiagnosticEnumeration/PercentComplete">
				<xsl:call-template name="DisplayEnumerationInProgress"/>
			</xsl:if>
			<xsl:if test="not(/OMA/DiagnosticEnumeration/PercentComplete)">
			<xsl:choose>
				<!-- Display Device Frame -->
				<xsl:when test="$displayview = 'DEVICEVIEW'">
					<xsl:call-template name="IFrameScript"/>
					<xsl:call-template name="ShowDeviceIFrame"/>
				</xsl:when>
				<!-- Display Test Frame -->
				<xsl:when test="$displayview = 'TESTVIEW'">
					<xsl:call-template name="IFrameScript"/>
					<xsl:call-template name="ShowTestIFrame"/>
				</xsl:when>
				<xsl:when test="$displayview = 'ENUMERATEALL'">
					<xsl:attribute name="email">false</xsl:attribute>
					<xsl:attribute name="expand">false</xsl:attribute>
					<xsl:call-template name="ParentFrameScript"/>
					<xsl:call-template name="ParentFrame">
						<xsl:with-param name="Msg" select="$strTESTEXECUTINGMSG"/>
					</xsl:call-template>					
				</xsl:when>
				<xsl:when test="$displayview = 'ADDDEVICETESTPAIR'"/>
				<!-- Display the Window Frame -->
				<xsl:otherwise>
					<xsl:attribute name="email">false</xsl:attribute>
					<xsl:attribute name="expand">false</xsl:attribute>
					<xsl:call-template name="ParentFrameScript"/>
					<xsl:call-template name="ParentFrame"/>
				</xsl:otherwise>
			</xsl:choose>
			</xsl:if>
		</DataArea>
	</xsl:template>
	<!-- ###################   Display Parent Frame ################# -->
	<xsl:template name="ParentFrame">
		<xsl:param name="Msg"/>
		<CustomButton>
			<Data name="preview">
				<xsl:attribute name="display"><xsl:value-of select="$strREVIEWSELECTION"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="$strREVIEWSELECTION"/></xsl:attribute>
				<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticReviewWebPlugin&amp;ct=<xsl:value-of select="/OMA/Component"/>&amp;snb=<xsl:value-of select="/OMA/Snb"/>&amp;lsnb=Review</xsl:attribute>
			</Data>
		</CustomButton>
		<CustomButton>
			<Data name="renumerate">
				<xsl:attribute name="display"><xsl:value-of select="$strREENUMERATE"/></xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="$strREENUMERATE"/></xsl:attribute>
				<xsl:attribute name="href">/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticSelectionWebPlugin&amp;action=EnumerateAll&amp;ct=<xsl:value-of select="/OMA/Component"/>&amp;snb=<xsl:value-of select="/OMA/Snb"/>&amp;lsnb=Select</xsl:attribute>
			</Data>
		</CustomButton>
		<!-- ###################    Display Page Title   ################### -->
		<xsl:call-template name="DisplayPageTitle"/>
		<!-- User Clicked Renumeration and tests are in progress -->
		<xsl:if test="not($Msg='')">
			<ListData>
				<Data name="displaymsg">
					<xsl:attribute name="value"><xsl:value-of select="$Msg"/></xsl:attribute>
				</Data>
			</ListData>
		</xsl:if>
		<!-- Display radio buttons -->
		<TableData>
			<xsl:call-template name="DeviceTestView"/>
		</TableData>
		<!-- Display 2 Iframes -->
		<SelectionDataUI>
			<SelectionTableUI id="DeviceSelectionFrame" width="54%" href="/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticSelectionWebPlugin&amp;action=ViewDisplay&amp;display=DEVICEVIEW"/>
			<ResultTableUI id="TestSelectionFrame" width="44%" href="/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticSelectionWebPlugin&amp;action=ViewDisplay&amp;display=TESTVIEW&amp;DisplayChoice=1&amp;DeviceParentLocation=&amp;DeviceLocation=System Board"/>
		</SelectionDataUI>
	</xsl:template>
	<!-- ################### This controls display of Devices ####################-->
	<xsl:template name="ShowDeviceIFrame">
		<SelectionData scrollablecontent="true">
			<SelectionTable>
				<Header>
					<Data name="displaydevicesheader">
						<xsl:attribute name="value"><xsl:value-of select="$strAVAILABLEDEVICES"/></xsl:attribute>
					</Data>
				</Header>
				<xsl:apply-templates select="/OMA/TestCollection" mode="DisplayDevices"/>
			</SelectionTable>
		</SelectionData>
	</xsl:template>
	<!-- ################### Set up Radio buttons  ################### -->
	<xsl:template name="DeviceTestView">
		<Row>
			<Data type="radio" align="center">
				<xsl:attribute name="name">DisplayTestCriteria</xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="$strALLTESTS"/></xsl:attribute>
				<xsl:attribute name="event">onClick</xsl:attribute>
				<xsl:attribute name="handler">javascript:changeTestView();</xsl:attribute>
				<xsl:attribute name="returnvalue">1</xsl:attribute>
				<xsl:if test="(/OMA/DisplayChoice = '1') or (not(/OMA/DisplayChoice))">
					<xsl:attribute name="state">1</xsl:attribute>
				</xsl:if>
			</Data>
			<Data type="radio" align="center">
				<xsl:attribute name="name">DisplayTestCriteria</xsl:attribute>
				<xsl:attribute name="value"><xsl:value-of select="$strTESTCURRENTNODE"/></xsl:attribute>
				<xsl:attribute name="event">onClick</xsl:attribute>
				<xsl:attribute name="handler">javascript:changeTestView();</xsl:attribute>
				<xsl:attribute name="returnvalue">0</xsl:attribute>
				<xsl:if test="(/OMA/DisplayChoice = '0')">
					<xsl:attribute name="state">1</xsl:attribute>
				</xsl:if>
			</Data>
		</Row>
	</xsl:template>
	<!-- ##########  Create Collection XML and Display Tests    ############################ -->
	<xsl:template match="TestCollection" mode="DisplayDevices">
		<xsl:for-each select="Device">
			<xsl:call-template name="DeviceMatch"/>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="DeviceMatch">
		<Row tree="expand">
			<!-- Image id ................................tag -->
			<xsl:attribute name="name">expand<xsl:value-of select="@location"/>!<xsl:value-of select="@parentlocation"/></xsl:attribute>
			<SelectDataItem>
				<!-- Display a blank box in case there are children elements -->
				<xsl:if test="not(Device)">
					<Data>
						<xsl:attribute name="width">20</xsl:attribute>
					</Data>
				</xsl:if>
				<!-- Input checkbox id = name................................ -->
				<Data>
					<xsl:attribute name="name">CurrentDevice</xsl:attribute>
					<xsl:attribute name="type">radio</xsl:attribute>
					<xsl:attribute name="width">20</xsl:attribute>
					<xsl:attribute name="event">onClick</xsl:attribute>
					<xsl:attribute name="handler">javascript:showTests('<xsl:value-of select="@location"/>' ,'<xsl:value-of select="@parentlocation"/>',this);</xsl:attribute>
					<xsl:attribute name="returnvalue"><xsl:value-of select="@location"/><xsl:value-of select="$SEPARATOR"/><xsl:value-of select="@parentlocation"/></xsl:attribute>
					<xsl:if test="(not(/OMA/DisplayChoice) and (count(ancestor::Device)) = 0)">
						<xsl:attribute name="state">1</xsl:attribute>
					</xsl:if>
					<xsl:if test="( (count(Test) =0) and (count(Device) =0) )">
						<xsl:attribute name="state">2</xsl:attribute>
					</xsl:if>
				</Data>
			</SelectDataItem>
			<ColumnData>
				<!-- Display Text ................................ -->
				<Data align="left">
					<xsl:attribute name="value"><xsl:value-of select="@name"/></xsl:attribute>
				</Data>
					<Data type="icon" align="right">
					<xsl:attribute name="name">STATUSIMG</xsl:attribute>
					<xsl:attribute name="alt"><xsl:value-of select="@devicestatusdescription"/></xsl:attribute>
					<xsl:choose>
						<xsl:when test="not(@devicestatus='0')">
							<xsl:attribute name="value">/oma/images/non-critical.gif</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="value">/oma/images/blank.gif</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
				</Data>
				
				<Data type="icon" align="right" link="true">
					<xsl:attribute name="name">INFOIMG<xsl:value-of select="@parentlocation"/><xsl:value-of select="@location"/>					</xsl:attribute>
					<xsl:attribute name="alt"><xsl:value-of select="@description"/></xsl:attribute>
					<xsl:attribute name="href">#</xsl:attribute>
					<xsl:choose>
						<xsl:when test="(not(/OMA/DisplayChoice) and (count(ancestor::Device)) = 0)">
							<xsl:attribute name="value">/oma/images/information.gif</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="value">/oma/images/blank.gif</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<EventHandler>
					     <xsl:attribute name="event">onclick</xsl:attribute>
					<!--FiX DFCT 107519-->
					<!--			
					     <xsl:attribute name="handler">window.open("/servlet/HelpArea?plugin=com.dell.omaha.webplugins.DiagnosticHelpTemplateWebPlugin&amp;package=<xsl:value-of select="./Test/Package/@basename"/>", "Oldiags", "height=420,width=630,scrollbars=yes,toolbar=no,menubar=no,resizable=yes,location=no,directories=no,status=no").focus();</xsl:attribute>
-->
					     <xsl:attribute name="handler">javascript:openHelp(this,'<xsl:value-of select="./Test/Package/@basename"/>');</xsl:attribute>
					</EventHandler>
				</Data>
			
			</ColumnData>
			<xsl:for-each select="Device">
				<xsl:sort select="normalize-space(@sortname)" data-type="text" order="ascending"/>
					<xsl:sort select="@sortindex" data-type="number" order="ascending"/>
				<ChildrenRows>
					<xsl:call-template name="DeviceMatch"/>
				</ChildrenRows>
			</xsl:for-each>
		</Row>
	</xsl:template>
	<!-- ##################  This controls display of Tests in the bottom frame ######### -->
	<xsl:template name="ShowTestIFrame">
		<SelectionData scrollablecontent="true">
			<SelectionTable>
				<xsl:apply-templates select="/OMA/TestCollection" mode="DisplayTests"/>
			</SelectionTable>
		</SelectionData>
		<HTMLData>
			<iframe id="AddTest" name="AddTest" style="visibility: hidden; height: 1px; width: 1px; top: 0px; left: 0px; position: absolute; z-index: -1" src="/oldiags/docs/blank.html"/>
		</HTMLData>
	</xsl:template>
	<!-- Display all tests matching criteria -->
	<xsl:template match="TestCollection" mode="DisplayTests">
		<xsl:if test="not(/OMA/DeviceLocation)">
			<xsl:call-template name="NoTestsToDisplay"/>
		</xsl:if>
		<xsl:if test="(/OMA/DeviceLocation)">
			<Header>
				<Data type="text" align="center">
					<xsl:attribute name="name">DisplaySelectionText</xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="$strAVAILABLETESTS"/></xsl:attribute>
				</Data>
			</Header>
			<xsl:variable name="loc" select="/OMA/DeviceLocation"/>
			<xsl:variable name="parentloc" select="/OMA/DeviceParentLocation"/>
			<xsl:apply-templates select="//Device[@location=$loc and @parentlocation=$parentloc]" mode="TestMatch"/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="Device" mode="TestMatch">
		<xsl:variable name="choice" select="/OMA/DisplayChoice"/>
		<xsl:choose>
			<xsl:when test="$choice = '0'">
				<xsl:if test="count(Test)=0">
					<xsl:call-template name="NoTestsToDisplay"/>
				</xsl:if>
				<xsl:if test="count(Test)!=0">
					<xsl:for-each select="Test">
						<xsl:call-template name="ShowTestListing"/>
					</xsl:for-each>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="AllApplicableTests" select=".//Test"/>
				<xsl:variable name="TotalTests" select="count(.//Test)"/>
				<xsl:variable name="PrecedingDuplicateTests" select="count($AllApplicableTests[@name=preceding::Test/@name])"/>
				<xsl:variable name="FollowingDuplicateTests" select="count($AllApplicableTests[@name=following::Test/@name])"/>
				<xsl:choose>
					<xsl:when test="$TotalTests=0">
						<xsl:call-template name="NoTestsToDisplay"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:if test="(($PrecedingDuplicateTests &gt; 0 and $TotalTests != $PrecedingDuplicateTests) or ($FollowingDuplicateTests &gt; 0 and $TotalTests != $FollowingDuplicateTests))">
							<xsl:for-each select="$AllApplicableTests[not(@name=preceding::Test/@name)]">
								<xsl:call-template name="ShowTestListing"/>
							</xsl:for-each>
						</xsl:if>
						<xsl:if test="(($PrecedingDuplicateTests &gt; 0 and $TotalTests = $PrecedingDuplicateTests) or ($FollowingDuplicateTests &gt; 0 and $TotalTests = $FollowingDuplicateTests) or ($PrecedingDuplicateTests =0 and $FollowingDuplicateTests = 0))">
							<xsl:for-each select="$AllApplicableTests">
								<xsl:call-template name="ShowTestListing"/>
							</xsl:for-each>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template name="ShowTestListing">
		<Row tree="fixed">
			<!-- Image id ................................tag -->
			<SelectDataItem>
				<!-- Display a blank box in case there are children elements -->
				<!-- Input checkbox id = name................................ -->
				<Data type="icon" name="diagbullet" align="center" value="/oldiags/images/diagbullet.gif" link="false"/>
			</SelectDataItem>
			<ColumnData>
				<!-- Display Text ................................ -->
				<Data align="left" width="500">
					<xsl:attribute name="value"><xsl:value-of select="@name"/></xsl:attribute>
				</Data>
				<Data display="Add" width="20" link="true">
					<xsl:attribute name="value"><xsl:value-of select="$strAddTests"/></xsl:attribute>
					<xsl:attribute name="name"><xsl:value-of select="@name"/></xsl:attribute>
					<xsl:attribute name="href">javascript:selectTests("<xsl:value-of select="@name"/>" , "<xsl:value-of select="/OMA/DeviceLocation"/>","<xsl:value-of select="/OMA/DeviceParentLocation"/>","<xsl:value-of select="@index"/>", "<xsl:value-of select="./Package/@uniqueid"/>", "<xsl:value-of select="/OMA/DisplayChoice"/>");</xsl:attribute>
				</Data>
				<Data type="icon" value="/oma/images/blank.gif">
					<xsl:attribute name="name">img<xsl:value-of select="@name"/></xsl:attribute>
				</Data>
			</ColumnData>
			<ChildrenRows/>
		</Row>
	</xsl:template>
	<!-- Use this template to display text when no tests are selected -->
	<xsl:template name="NoTestsToDisplay">
		<Row tree="expand">
			<SelectDataItem/>
			<!-- Display a blank box in case there are children elements -->
			<ColumnData>
				<Data align="left">
					<xsl:attribute name="value"><xsl:value-of select="$strNODEVICESELECTED"/></xsl:attribute>
				</Data>
			</ColumnData>
		</Row>
	</xsl:template>
	<!-- ##################################
					Javascript Code 
	      ################################## -->
	<xsl:template name="IFrameScript">
		<script language="javascript">
		//Added for Fix 107519
		var chk="System Board";

 				var baseurl = "/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticSelectionWebPlugin" ;

				function selectTests(elem, DeviceLocation, DeviceParentLocation, TestIndex, UniqueId, DisplayChoice) {
				
					var action                      = "&amp;action=AddDeviceTestPair"
					var deviceparentlocation   = "&amp;DeviceParentLocation=" + DeviceParentLocation ;
					var devicelocation            = "&amp;DeviceLocation=" + DeviceLocation ;
					var testindex                   = "&amp;TestIndex=" + TestIndex ;
					var uniqueId             = "&amp;UniqueId=" + UniqueId ;
					var showalltestoption       = "&amp;DisplayChoice=" + DisplayChoice ;

					document.getElementById('AddTest').src = baseurl + action + devicelocation + deviceparentlocation + testindex + uniqueId + showalltestoption ;

					var imagename = "img" + elem ;
					var img = document.getElementById(imagename);
					img.src = "/oma/images/check.gif";
				}
				
				//Function added for Fix 107519
				function openHelp(obj,pkg)
				{
				img = obj.name.substring(7);
				if(chk==img)
				{
					window.open("/servlet/HelpArea?plugin=com.dell.omaha.webplugins.DiagnosticHelpTemplateWebPlugin&amp;package="+pkg, "Oldiags", "height=420,width=630,scrollbars=yes,toolbar=no,menubar=no,resizable=yes,location=no,directories=no,status=no").focus();
				}
				}

				//For Fix 107519
				function showTests(location, parentloc,obj) {
				if(obj!=null)
				chk = obj.value.substring(obj.value.indexOf('_')+1)+obj.value.substring(0,obj.value.indexOf('_'));
					// change the info image icon
					var infoimgname = "INFOIMG" + parentloc + location ;
					for ( var i = 0 ; i &lt; document.images.length ; i++) {
						var elem = document.images[i] ;
						var regexp = "^INFOIMG" ;
						if (elem.name.match(regexp)) {
							if (elem.name == infoimgname) {
								elem.src = "/oma/images/information.gif" ;
							}
							else {
								elem.src = "/oma/images/blank.gif" ;
							}
						}
					}

					// Determine Display Criteria
					var displaychoice ;
					for (var i = 0 ; i &lt;parent.document.dataarea.length ; i++ ) {
							var elem = parent.document.dataarea.elements[i];
							if (elem.name == 'DisplayTestCriteria' &amp;&amp; elem.checked) 
								displaychoice = elem.value ;
					}
					parent.updateTestView(location,parentloc, displaychoice);
				}
				
		</script>
	</xsl:template>
	<xsl:template name="ParentFrameScript">
		<xsl:attribute name="method">get</xsl:attribute>
		<script language="javascript">
					function updateTestView(location, parentloc, choice) {
					    // reset info image to current 1 selected
						
						var baseurl = "/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticSelectionWebPlugin&amp;action=ViewDisplay&amp;display=TESTVIEW";
						var param = "&amp;DeviceLocation=" + location + "&amp;DeviceParentLocation=" + parentloc + "&amp;DisplayChoice=" + choice ;
						var iframeobj = new Object() ;
						
						iframeobj = document.getElementById("TestSelectionFrame");
						iframeobj.src = baseurl + param ;
					}
					function enumerateAll() {
						document.dataarea.action = "/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticSelectionWebPlugin&amp;action='EnumerateAll'" ;
						document.dataarea.method = 'get';
						document.dataarea.submit();
					}
	
					function changeTestView() {
						var deviceinfo ;
						var deviceselected = 0 ;
						var framehandle ;

						if (document.all)	 
							framehandle = document.frames[0]; // For IE..
						else
							framehandle = document.getElementById("DeviceSelectionFrame").contentWindow ; // For Netscape ....

						for (var i = 0 ; i  &lt; framehandle.document.dataarea.length ; i++ ) {
							var elem = framehandle.document.dataarea.elements[i];
							var regexp = "^CurrentDevice" ;
							if (elem.name.match(regexp) &amp;&amp; elem.checked) {
								deviceinfo = elem.value.split('<xsl:value-of select="$SEPARATOR"/>') ;
								deviceselected = 1;
							}
						}
						if (deviceselected == 0){
							alert("<xsl:value-of select="$strNODEVICESELECTED"/>");
							return ;
						} else {
							var location   = deviceinfo[0] ;
							var parentlocation = deviceinfo[1];		
							//Changed for Fix107519
							framehandle.showTests(location, parentlocation,null) ;		
						}
					}
		</script>
	</xsl:template>
	<xsl:template name="DisplayPageTitle">
		<PageTitle>
			<xsl:attribute name="display"><xsl:value-of select="$strPAGETITLE"/></xsl:attribute>
		</PageTitle>
	</xsl:template>
	<xsl:template name="DisplayEnumerationInProgress">
		<xsl:attribute name="submitdisplay"><xsl:value-of select="$strRENUMSTATUS"/></xsl:attribute>
		<xsl:attribute name="submit">/servlet/DataArea?plugin=com.dell.omaha.webplugins.DiagnosticEnumerationWebPlugin&amp;ct=<xsl:value-of select="/OMA/Component"/>&amp;snb=<xsl:value-of select="/OMA/Snb"/>&amp;lsnb=Select</xsl:attribute>
		<xsl:attribute name="printable">false</xsl:attribute>
		<xsl:attribute name="email">false</xsl:attribute>
		<xsl:attribute name="export">false</xsl:attribute>
		<xsl:call-template name="DisplayPageTitle"/>
		<script>
			function validate() {
				 return true;	
			}
		</script>
		<PromptText>
			<xsl:value-of select="$strRENUMMESSAGE"/>
		</PromptText>		
	</xsl:template>
	<xsl:template match="IncludePath">
		<xsl:element name="xsl:include">
			<xsl:attribute name="href">file:<xsl:value-of select="."/></xsl:attribute>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>
